# pyFontAwesome47

[Font Awesome-4.7](https://fontawesome.com/v4.7/) for python desktop usage.

* https://fontawesome.com/v4.7/cheatsheet/

## Install

```
pip install fontawesome47
```

## Usage

```python
import fontawesome47

path = fontawesome47.get_path() # pathlib.Path

data = fontawesome47.get_data() # bytes
```
